##
##  borg.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package versions
%define       V_borg_base  1.2.8
%define       V_borg_snap  20240403
%define       V_python     3.11

#   package information
Name:         borg
Summary:      Deduplicating Archiver With Compression and Encryption
URL:          https://www.borgbackup.org/
Vendor:       Jonas Borgström, The Borg Collective
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Filesystem
License:      BSD
Version:      %{V_borg_base}.%{V_borg_snap}
Release:      20240403

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/borg/borg-%{V_borg_snap}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  python, python-setup
PreReq:       python, python-setup

%description
    BorgBackup (short: Borg) gives you: Space efficient storage of
    backups; Secure, authenticated encryption; Compression: LZ4, zlib,
    LZMA, zstd; and more.

%track
    prog borg:base = {
        version   = %{V_borg_base}
        url       = https://github.com/borgbackup/borg/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }
    prog borg:snap = {
        version   = %{V_borg_snap}
        url       = http://download.openpkg.org/components/versioned/borg/
        regex     = borg-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n borg

%build

%install
    #   install package
    export HOME=`pwd`
    %{l_prefix}/bin/python -m pip \
        install \
        --root=$RPM_BUILD_ROOT \
        --prefix=%{l_prefix}/lib/borg \
        --isolated \
        --ignore-installed \
        --no-warn-script-location \
        *

    #   remove problematic files
    rm -f "$RPM_BUILD_ROOT%{l_prefix}/lib/borg/lib/python%{V_python}/site-packages/setuptools/command/launcher manifest.xml"
    rm -f "$RPM_BUILD_ROOT%{l_prefix}/lib/borg/lib/python%{V_python}/site-packages/setuptools/script (dev).tmpl"

    #   provide executable wrappers
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin
    for exe in `cd $RPM_BUILD_ROOT%{l_prefix}/lib/borg/bin && ls *`; do
        (   echo "#!/bin/sh"
            echo "PYTHONPATH=\"%{l_prefix}/lib/borg/lib/python%{V_python}/site-packages:%{l_prefix}/lib/python/site-packages\""
            echo "export PYTHONPATH"
            echo "exec %{l_prefix}/lib/borg/bin/$exe \${1+\"\$@\"}"
        ) >$RPM_BUILD_ROOT%{l_prefix}/bin/$exe
        chmod a+x $RPM_BUILD_ROOT%{l_prefix}/bin/$exe
    done

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

